@@ -256,19 +256,26 @@ def getClassFullName(classItem):
     return getattr(classItem, '__module__') + '.' + getattr(classItem, '__name__')
 
 
-def execute(*pars):
+def execute(*pars, showCmd=True, ignoreError=False):
+    cmd = ' '.join(pars)
+    if showCmd:
+        info(cmd)
     p = subprocess.Popen(
-        ' '.join(pars),
+        cmd,
         shell=True,
         stdout=subprocess.PIPE,
         stderr=subprocess.PIPE
     )
     outBytes, errBytes = p.communicate()
     p.kill()
+    if not ignoreError and errBytes:
+        error(f"output: {outBytes}")
+        error(f"error: {errBytes}")
+        raise Exception("执行命令出错")
     return p.returncode, outBytes, errBytes
 
 
-def executeWinScp(winscpExe, keyFile, server, commandAry, showCmd=False):
+def executeWinScp(winscpExe, keyFile, server, commandAry, showCmd=True):
     logFile = getPath(pathlib.Path.home(), "executeWinScp.log")
     remove(logFile)
     ary = [
@@ -283,13 +290,11 @@ def executeWinScp(winscpExe, keyFile, server, commandAry, showCmd=False):
     ]
     # /console
     cmd = f'{winscpExe} /log={logFile} /loglevel=0 /command ' + ' '.join('"%s"' % x for x in ary)
-    if showCmd:
-        info(cmd)
-    return execute(cmd)
+    return execute(cmd, showCmd=showCmd)
 
 
 def executeTry(*parList, output=None, error=None):
-    _code, outputBytes, errorBytes = execute(*parList)
+    _code, outputBytes, errorBytes = execute(*parList, showCmd=False, ignoreError=True)
     if type(output) == str:
         output = output.encode()
     if output and output not in outputBytes:
